==> viha-5.15.tar.gz: viha-5.15/jarjesto-ok.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

# sanity check functions for database additions, modifications and
# deletions.
# general format is ret = table_what_ok(&$msg,$id, ...)
# msg is error/warning message
# id is the main id of the record in question, new record => id = ''
# return codes:
#  0 (all ok, msg undefined)
#  1 (warnings in msg)
#  2 (fatal, reason in msg)

# jarjesto tarkastusfunktiot

function jarjesto_ok(&$msg,$id,$jarjesto,$alue_id,$paivystys_id) {
  global $table;
  
  $msg = '';
  $ret = 0;
  
  if ($id != "") {
    $id_sql = "AND id != $id";
    $modify = true;
    $tail = " Ei voi muuttaa.";
  } else {
    $modify = false;
    $tail = " Ei voi list.";
  }

  $ret_p = permission_ids($msg,$alue_id,$paivystys_id);
  if ($ret_p == 2) {
    $msg .= $tail;
    return 2;
  } else {
    $ret = $ret_p;
  }
  
  # jos muutos, tarkastetaan ett on oikeus mys oleviin tietoihin
  if ($modify) {
    $w_alue_id = tab_col_id($table,"alue_id",$id);
    $w_paivystys_id = tab_col_id($table,"paivystys_id",$id);
    $ret_p = permission_ids($msg,$w_alue_id,$w_paivystys_id);
    if ($ret_p == 2) {
      $msg .= $tail;
      return 2;
    } else {
      $ret = $ret_p;
    }
  } # modify
  
  # kovakoodatut tietueet
  if (($id == "1") || ($id == "2")) {
    $msg = "Jrjestt numeroilla 1 ja 2 on suojattu.";
    $msg .= $tail;
    return 2;
  }

  # tarpeelliset kentt
  if ($jarjesto == '') {
    $msg = 'Jrjestn nimi on pakollinen tieto.';
    $msg .= $tail;
    return 2;
  }

  # duplikaatit
  $dup = ota_yksi("
SELECT id
FROM $table
WHERE jarjesto = '$jarjesto'
      $id_sql
");
  if ($dup != '') {
    $msg = "Tllainen jrjest on jo olemassa (id=$dup)";
    $msg .= $tail;
    return 2;
  } 

  return $ret;
}

function jarjesto_add_ok(&$msg,$jarjesto,$alue_id,$paivystys_id) {
  return jarjesto_ok($msg,'',$jarjesto,$alue_id,$paivystys_id);
}

function jarjesto_save_ok(&$msg,$id,$jarjesto,$alue_id,$paivystys_id) {
  return jarjesto_ok($msg,$id,$jarjesto,$alue_id,$paivystys_id);
}

function jarjesto_remove_ok(&$msg, $id, $log = true) {
  $msg = '';
  $ret = 0;

  $ret_p = permission_tab($msg, "jarjesto", $id, $log);
  if ($ret_p == 2) {
    return 2;
  } else {
    $ret = $ret_p;
  }
  
  # jrjestj 1 ja 2 ei voi poistaa
  if (($id == "1") || ($id == "2")) {
    $msg = "Jrjestj numeroilla 1 ja 2 ei voi poistaa.";
    return 2;
  }

  # jos jrjestn on viittauksia henkiliss, laitteissa tai tavarassa,
  # sit ei voi poistaa
  $ref = ota_yksi("SELECT COUNT(*) FROM hlo WHERE jarjesto_id = $id");
  if ($ref != 0) {
    $msg = "Thn jrjestn on viittauksia $ref eri henkilss. Sit ei voi
 poistaa ennen kuin viittaukset on siivottu.";
    return 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM laite WHERE jarjesto_id = $id");
  if ($ref != 0) {
    $msg = "Thn jrjestn on viittauksia $ref eri viestivlineess.
 Sit ei voi poistaa ennen kuin viittaukset on siivottu.";
    return 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM tavara WHERE jarjesto_id = $id");
  if ($ref != 0) {
    $msg = "Thn jrjestn on viittauksia $ref eri tavarassa.
 Sit ei voi poistaa ennen kuin viittaukset on siivottu.";
    return 2;
  }
  
  return $ret;
}

?>

<!-- RCS $Id: jarjesto-ok.php,v 1.8 2009/03/24 09:11:02 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/jarjesto-ok.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

# sanity check functions for database additions, modifications and
# deletions.
# general format is ret = table_what_ok(&$msg,$id, ...)
# msg is error/warning message
# id is the main id of the record in question, new record => id = ''
# return codes:
#  0 (all ok, msg undefined)
#  1 (warnings in msg)
#  2 (fatal, reason in msg)

# jarjesto tarkastusfunktiot

function jarjesto_ok(&$msg,$id,$jarjesto,$alue_id) {
  global $table;
  
  $msg = '';
  $ret = 0;
  
  if ($id != "") {
    $id_sql = "AND id != $id";
    $modify = true;
    $tail = " Ei voi muuttaa.";
  } else {
    $modify = false;
    $tail = " Ei voi list.";
  }

  $ret_p = permission_ids($msg,$alue_id,1);
  if ($ret_p == 2) {
    $msg .= $tail;
    return 2;
  } else {
    $ret = $ret_p;
  }
  
  # jos muutos, tarkastetaan ett on oikeus mys oleviin tietoihin
  if ($modify) {
    $w_alue_id = tab_col_id($table,"alue_id",$id);
    $ret_p = permission_ids($msg,$w_alue_id,1);
    if ($ret_p == 2) {
      $msg .= $tail;
      return 2;
    } else {
      $ret = $ret_p;
    }
  } # modify
  
  # kovakoodatut tietueet
  if (($id == "1") || ($id == "2")) {
    $msg = "Jrjestt numeroilla 1 ja 2 on suojattu.";
    $msg .= $tail;
    return 2;
  }

  # tarpeelliset kentt
  if ($jarjesto == '') {
    $msg = 'Jrjestn nimi on pakollinen tieto.';
    $msg .= $tail;
    return 2;
  }

  # duplikaatit
  $dup = ota_yksi("
SELECT id
FROM $table
WHERE jarjesto = '$jarjesto'
      $id_sql
");
  if ($dup != '') {
    $msg = "Tllainen jrjest on jo olemassa (id=$dup)";
    $msg .= $tail;
    return 2;
  } 

  return $ret;
}

function jarjesto_add_ok(&$msg,$jarjesto,$alue_id) {
  return jarjesto_ok($msg,'',$jarjesto,$alue_id);
}

function jarjesto_save_ok(&$msg,$id,$jarjesto,$alue_id) {
  return jarjesto_ok($msg,$id,$jarjesto,$alue_id);
}

function jarjesto_remove_ok(&$msg, $id, $log = true) {
  $msg = '';
  $ret = 0;

  $ret_p = permission_tab($msg, "jarjesto", $id, $log);
  if ($ret_p == 2) {
    return 2;
  } else {
    $ret = $ret_p;
  }
  
  # jrjestj 1 ja 2 ei voi poistaa
  if (($id == "1") || ($id == "2")) {
    $msg = "Jrjestj numeroilla 1 ja 2 ei voi poistaa.";
    return 2;
  }

  # jos jrjestn on viittauksia henkiliss, laitteissa tai tavarassa,
  # sit ei voi poistaa
  $ref = ota_yksi("SELECT COUNT(*) FROM hlo WHERE jarjesto_id = $id");
  if ($ref != 0) {
    $msg = "Thn jrjestn on viittauksia $ref eri henkilss. Sit ei voi
 poistaa ennen kuin viittaukset on siivottu.";
    return 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM laite WHERE jarjesto_id = $id");
  if ($ref != 0) {
    $msg = "Thn jrjestn on viittauksia $ref eri viestivlineess.
 Sit ei voi poistaa ennen kuin viittaukset on siivottu.";
    return 2;
  }
  $ref = ota_yksi("SELECT COUNT(*) FROM tavara WHERE jarjesto_id = $id");
  if ($ref != 0) {
    $msg = "Thn jrjestn on viittauksia $ref eri tavarassa.
 Sit ei voi poistaa ennen kuin viittaukset on siivottu.";
    return 2;
  }
  
  return $ret;
}

?>

<!-- RCS $Id: jarjesto-ok.php,v 1.9 2009/10/05 11:03:13 riku Exp $ -->
